<p>
  <b style="font-size:120%">
    {{ term.text }}
    {% if parentterms %}
    ({{ parentterms }})
    {% endif %}
  </b>
  {% for t in term_tags %}
  <span class="termpopup-tag">{{ t }}</span>
  {% endfor %}
</p>

{% if flashmsg %}
<p class="small-flash-notice">{{ flashmsg }}</p>
{% endif %}

{% if term.romanization %}
<p><i>{{ term.romanization }}</i></p>
{% endif %}

{% for img, tooltip in term_images.items() %}
<img class="tooltip-image" src="{{ img }}" tooltip="{{ tooltip }}"/>
{% endfor %}

{% if term_translation != "" %}
<p>{{ term_translation | replace("\n", '<br />') | safe }}</p>
{% endif %}

<p>
</p>

{% if parentdata | length > 0 %}
<div style="margin-top: 1.5em;">
  {% for p in parentdata %}
  <p>
    <b>{{ p.term }}</b>
    {% if p.roman != "" %}<i>({{ p.roman }})</i>{% endif %}
    {% for t in p.tags %}
    <span class="termpopup-tag">{{ t }}</span>
    {% endfor %}
    {% if p.trans != "" %}
    <br />
    {{ p.trans | replace("\n", '<br />') | safe }}
    {% endif %}
  </p>
  {% endfor %}
</div>
{% endif %}

{% if componentdata | length > 0 %}

<div style="margin-top: 1.5em;">
  <p><i>Components</i></p>

  {% for p in componentdata %}
  <p>
    <b>{{ p.term }}</b>
    {% if p.roman != "" %}<i>({{ p.roman }})</i>{% endif %}
    {% for t in p.tags %}
    <span class="termpopup-tag">{{ t }}</span>
    {% endfor %}
    {% if p.trans != "" %}
    <br />
    {{ p.trans | replace("\n", '<br />') | safe }}
    {% endif %}
  </p>
  {% endfor %}
</div>
{% endif %}
